PDFPreferences class

PDF reader preferences for Flureadium.

Based on Readium PDF navigator preferences:

  • fit: How the page fits in the viewport (width, contain)
  • scrollMode: Scroll orientation (horizontal, vertical)
  • pageLayout: Single page or double spread
  • offsetFirstPage: Offset for first page in spreads (for covers)

Constructors

PDFPreferences({PDFFit? fit, PDFScrollMode? scrollMode, PDFPageLayout? pageLayout, bool? offsetFirstPage})
PDFPreferences.fromJsonMap(Map<String, dynamic> map)
factory

Properties

fit PDFFit?
How the page fits in the viewport.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offsetFirstPage bool?
Whether to offset the first page in double-page spreads (for covers).
getter/setter pair
pageLayout PDFPageLayout?
Page layout mode.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollMode PDFScrollMode?
Scroll orientation.
getter/setter pair

Methods

copyWith({PDFFit? fit, PDFScrollMode? scrollMode, PDFPageLayout? pageLayout, bool? offsetFirstPage}) PDFPreferences
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited