ReadiumReaderWidget class
A ReadiumReaderWidget wraps a native Kotlin/Swift Readium navigator widget.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ReadiumReaderWidget
Constructors
- ReadiumReaderWidget({required Publication publication, Widget loadingWidget = const Center(child: CircularProgressIndicator()), Locator? initialLocator, VoidCallback? onTap, VoidCallback? onGoLeft, VoidCallback? onGoRight, VoidCallback? onSwipe, dynamic onExternalLinkActivated(String)?, void onLocatorChanged(Locator)?, VoidCallback? onReady, Key? key})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialLocator → Locator?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingWidget → Widget
-
final
- onExternalLinkActivated → dynamic Function(String)?
-
final
- onGoLeft → VoidCallback?
-
final
- onGoRight → VoidCallback?
-
final
- onLocatorChanged → void Function(Locator)?
-
final
- onReady → VoidCallback?
-
Called once when the native platform view has been created and all
EventChannel handlers are registered. Safe to subscribe to
Flureadium.onReaderStatusChanged, Flureadium.onTextLocatorChanged,
and Flureadium.onErrorEvent from within this callback on all platforms.
final
- onSwipe → VoidCallback?
-
final
- onTap → VoidCallback?
-
final
- publication → Publication
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited