onReady property
Called once when the widget is ready to accept stream subscriptions. On web, event channels are registered eagerly, so this fires from initState.
Implementation
final VoidCallback? onReady;
Called once when the widget is ready to accept stream subscriptions. On web, event channels are registered eagerly, so this fires from initState.
final VoidCallback? onReady;